@@ -139,7 +139,6 @@ def Numpy2GTiff(arr, gt, prj, fileout, format="GTiff", save_nodata_as=-9999, met
             ds.GetRasterBand(1).WriteArray(arr)
 
             if cog:
-                gdal.SetConfigOption('CPLErrorHandling', 'silent')
                 if verbose:
                     print(f"Creating a COG..", CO)
                 driver = gdal.GetDriverByName("COG")
@@ -147,11 +146,9 @@ def Numpy2GTiff(arr, gt, prj, fileout, format="GTiff", save_nodata_as=-9999, met
                 ds.BuildOverviews("NEAREST", CalculateOverviews(ds))
                 dst_ds = driver.CreateCopy(fileout, ds, False, CO)
                 ds = dst_ds
-                gdal.SetConfigOption('CPLErrorHandling', 'once')
 
             ds.FlushCache()
             ds = None
-
             return fileout
     return None
 
